# 一个基于STK的专门生成cage的测试库

依赖:

> 1. BOSSdir: single-point calculation
> 2. csh: shell scripts
> 3. stk: Chemical info lib
> 4. RDKit: Chemical info lib
> 5. openbabel
> 6. LAMMPS

赖的写了, 懂得都懂... :sleepy: